@@ -184,7 +184,7 @@ private Q_SLOTS:
         KIMAP::Session session(QStringLiteral("127.0.0.1"), 5989);
 
         auto job = new KIMAP::ListJob(&session);
-        job->setIncludeUnsubscribed(unsubscribed);
+        job->setOption(unsubscribed ? KIMAP::ListJob::IncludeUnsubscribed : KIMAP::ListJob::NoOption);
 
         QSignalSpy spy(job, &KIMAP::ListJob::mailBoxesReceived);
 
